import { Cancellable, OnExtensionSubscriber, OnNextSubscriber, OnTerminalSubscriber, Requestable } from "@rsocket/core";
export declare enum ConnectionStatus {
    DISCONNECTED = 0,
    REJECT = 1,
    CONNECTING = 2,
    CONNECTED = 3
}
export interface Auth {
    token?: string;
    simple?: {
        username: string;
        password: string;
    };
}
export interface RawPayload<T = any> {
    route: string;
    data?: T;
    encodeData?: boolean;
}
export interface FireAndForgotParam<T> {
    payload: RawPayload<T>;
}
export interface ResponseParam {
    payload: RawPayload;
    responderStream: OnNextSubscriber & Partial<OnTerminalSubscriber & OnExtensionSubscriber>;
}
export interface StreamParam {
    payload: RawPayload;
    initialRequestN: number;
    responderStream: OnNextSubscriber & Partial<OnTerminalSubscriber & OnExtensionSubscriber>;
}
export interface ChannelParam<T> {
    payload: RawPayload<T>;
    initialRequestN: number;
    isCompleted: boolean;
    responderStream: OnNextSubscriber & Partial<OnTerminalSubscriber & OnExtensionSubscriber & Requestable & Cancellable>;
}
export interface RsocketServer {
    name: string;
    url: string;
}
export interface RsocketServerLatency {
    name: string;
    latency: number;
}
export type StreamRequester = Requestable & Cancellable & OnExtensionSubscriber;
export type ChannelRequester = OnTerminalSubscriber & OnNextSubscriber & OnExtensionSubscriber & Requestable & Cancellable;
